==> builder-7.0.6-sources.jar: io/intino/magritte/builder/compiler/codegeneration/magritte/TemplateTags.java <==
package io.intino.magritte.builder.compiler.codegeneration.magritte;

public interface TemplateTags {

	String DOT = ".";
	String PARENT = "parent";
	String CHILD = "child";
	String TARGET_CONTAINER = "targetContainer";
	String RULE = "rule";
	String SIZE = "size";
	String STASH = "stash";
	String NATIVE = "native";
	String PARENT_SUPER = "parentSuper";
	String POSITION = "position";
	String AVAILABLE_ASPECT = "availableAspect";
	String META_LANGUAGE = "metaLanguage";
	String MODEL_TYPE = "modelType";
	String CONCEPT_LAYER = "conceptLayer";
	String DEFAULT = "default";
	String EMPTY = "empty";
	String PLATFORM = "Platform";
	String MAIN = "Main";
	String DECORABLE = "decorable";
	String SCOPE = "scope";
	String PRODUCT = "Product";
	String SIGNATURE = "signature";
	String OUTDEFINED = "outDefined";
	String EXTERNAL_CLASS = "externalClass";
	String FILE = "file";
	String LINE = "line";
	String IMPORTS = "imports";
	String INSTANCE = "instance";
	String COLUMN = "column";
	String LOCALE = "locale";
	String QN = "qn";
	String STASH_QN = "stashQn";
	String FLAG = "flag";
	String BODY = "body";
	String OWNER = "owner";
	String UID = "uid";
	String REQUIRED = "required";
	String CONTAINER = "container";
	String META_TYPE = "metaType";
	String ONE_OF = "oneOf";
	String CONTAINER_NAME = "containerName";
	String NATIVE_CONTAINER = "nativeContainer";
	String OUT_LANGUAGE = "generatedLanguage";
	String WORKING_PACKAGE = "workingPackage";
	String PARAMETER = "parameter";
	String NODE_TYPE = "nodeType";
	String ABSTRACT = "abstract";
	String WORD = "word";
	String PRIMITIVE = "primitive";
	String RETURN = "return";
	String META_ASPECT = "metaAspect";
	String ASPECT = "aspect";
	String CONSTRAINTS = "constraints";
	String ASSUMPTIONS = "assumptions";
	String COMPONENT = "component";
	String TARGET = "target";
	String METRIC = "metric";
	String LANGUAGE = "language";
	String DOC = "doc";
	String LAYER = "Layer";
	String PACKAGE = "package";
	String WITH = "with";
	String CONSTRAINT = "constraint";
	String ASSUMPTION = "assumption";
	String TAGS = "tags";
	String NODE = "node";
	String ROOT = "root";
	String NAME = "name";
	String SINGLE = "single";
	String TYPE = "type";
	String CONCEPT = "concept";
	String VALUE = "value";
	String VALUES = "values";
	String WORD_VALUES = "wordValues";
	String REFERENCE = "reference";
	String CREATE = "create";
	String INHERITED = "inherited";
	String PARENT_REF = "parentRef";
	String OVERRIDEN = "overriden";
	String VARIABLE = "variable";
	String WORDS = "words";
	String TERMINAL = "terminal";
	String MULTIPLE = "multiple";
	String INNER = "inner";
}

==> builder-8.0.1-sources.jar: io/intino/magritte/builder/compiler/codegeneration/magritte/TemplateTags.java <==
package io.intino.magritte.builder.compiler.codegeneration.magritte;

public interface TemplateTags {

	String DOT = ".";
	String PARENT = "parent";
	String CHILD = "child";
	String TARGET_CONTAINER = "targetContainer";
	String RULE = "rule";
	String SIZE = "size";
	String STASH = "stash";
	String NATIVE = "native";
	String PARENT_SUPER = "parentSuper";
	String POSITION = "position";
	String AVAILABLE_ASPECT = "availableAspect";
	String META_LANGUAGE = "metaLanguage";
	String MODEL_TYPE = "modelType";
	String CONCEPT_LAYER = "conceptLayer";
	String DEFAULT = "default";
	String EMPTY = "empty";
	String METAMETAMODEL = "Platform";
	String MAIN = "Main";
	String DECORABLE = "decorable";
	String SCOPE = "scope";
	String METAMODEL = "Product";
	String SIGNATURE = "signature";
	String OUTDEFINED = "outDefined";
	String EXTERNAL_CLASS = "externalClass";
	String FILE = "file";
	String LINE = "line";
	String IMPORTS = "imports";
	String INSTANCE = "instance";
	String COLUMN = "column";
	String LOCALE = "locale";
	String QN = "qn";
	String STASH_QN = "stashQn";
	String FLAG = "flag";
	String BODY = "body";
	String OWNER = "owner";
	String UID = "uid";
	String REQUIRED = "required";
	String CONTAINER = "container";
	String META_TYPE = "metaType";
	String ONE_OF = "oneOf";
	String CONTAINER_NAME = "containerName";
	String NATIVE_CONTAINER = "nativeContainer";
	String OUT_LANGUAGE = "generatedLanguage";
	String WORKING_PACKAGE = "workingPackage";
	String PARAMETER = "parameter";
	String NODE_TYPE = "nodeType";
	String ABSTRACT = "abstract";
	String WORD = "word";
	String PRIMITIVE = "primitive";
	String RETURN = "return";
	String META_ASPECT = "metaAspect";
	String ASPECT = "aspect";
	String CONSTRAINTS = "constraints";
	String ASSUMPTIONS = "assumptions";
	String COMPONENT = "component";
	String TARGET = "target";
	String METRIC = "metric";
	String LANGUAGE = "language";
	String DOC = "doc";
	String LAYER = "Layer";
	String PACKAGE = "package";
	String WITH = "with";
	String CONSTRAINT = "constraint";
	String ASSUMPTION = "assumption";
	String TAGS = "tags";
	String NODE = "node";
	String ROOT = "root";
	String NAME = "name";
	String SINGLE = "single";
	String TYPE = "type";
	String CONCEPT = "concept";
	String VALUE = "value";
	String VALUES = "values";
	String WORD_VALUES = "wordValues";
	String REFERENCE = "reference";
	String CREATE = "create";
	String INHERITED = "inherited";
	String PARENT_REF = "parentRef";
	String OVERRIDEN = "overriden";
	String PROPERTY = "variable";
	String WORDS = "words";
	String TERMINAL = "terminal";
	String MULTIPLE = "multiple";
	String INNER = "inner";
}
